@@ -58,7 +58,7 @@ class Logger:
         if location is None:
             location = self.location
         if labels is None:
-            labels = labels
+            labels = self.labels
         record = LogRecordDO(
             log_type = record_type,
             log_domain = domain,
